==> rmcfs_1.2.12.tar.gz: rmcfs/java/src/dmLab/mcfs/attributesRI/measuresRI/ImportanceMeasure.java <==
/*******************************************************************************
 * #-------------------------------------------------------------------------------
 * # Copyright (c) 2003-2016 IPI PAN.
 * # All rights reserved. This program and the accompanying materials
 * # are made available under the terms of the GNU Public License v3.0
 * # which accompanies this distribution, and is available at
 * # http://www.gnu.org/licenses/gpl.html
 * # 
 * #-------------------------------------------------------------------------------
 * # @description: data mining (dmLab) library that implements MCFS-ID algorithm
 * # @author: Michal Draminski [mdramins@ipipan.waw.pl]
 * # @company: Polish Academy of Sciences - Institute of Computer Science
 * # @homepage: http://www.ipipan.eu/
 * #-------------------------------------------------------------------------------
 * # Algorithm 'SLIQ' developed by Mariusz Gromada
 * # R Package developed by Michal Draminski & Julian Zubek
 * #-------------------------------------------------------------------------------
 * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
 * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
 * # "Monte Carlo feature selection for supervised classification", 
 * # BIOINFORMATICS 24(1): 110-117 (2008)
 * #-------------------------------------------------------------------------------
 *******************************************************************************/
package dmLab.mcfs.attributesRI.measuresRI;

import dmLab.classifier.attributeIndicators.AttributeIndicators;
import dmLab.mcfs.MCFSParams;
import dmLab.mcfs.attributesRI.ExperimentIndicators;

public abstract class ImportanceMeasure
{
    public static String MEASURE_PROJECTIONS = "projections";
    public static String MEASURE_CLASSIFIERS = "classifiers";
    public static String MEASURE_NODES = "nodes";
    public static String MEASURE_RI = "RI";
    public static String MEASURE_RINORM = "RI_norm";
    
    public String name;
    public MCFSParams cfg;
    
    //********************************    
    public ImportanceMeasure(MCFSParams cfg)
    {
        this.cfg=cfg;
    }
    //********************************
    public abstract void flush();
    //********************************
    public abstract double calcAttrImportance(ExperimentIndicators experimentIndicators, AttributeIndicators indicators);    
    //********************************
    public abstract double calcAttrImportance();
    //********************************
}

==> rmcfs_1.3.4.tar.gz: rmcfs/java/src/dmLab/mcfs/attributesRI/measuresRI/ImportanceMeasure.java <==
/*******************************************************************************
 * #-------------------------------------------------------------------------------
 * # dmLab 2003-2019
 * # All rights reserved. This program and the accompanying materials
 * # are made available under the terms of the GNU Public License v3.0
 * # which accompanies this distribution, and is available at
 * # http://www.gnu.org/licenses/gpl.html
 * # 
 * #-------------------------------------------------------------------------------
 * # @description: data mining (dmLab) library that implements MCFS-ID algorithm
 * # @author: Michal Draminski [mdramins@ipipan.waw.pl]
 * # @company: Polish Academy of Sciences - Institute of Computer Science
 * # @homepage: http://www.ipipan.eu/
 * #-------------------------------------------------------------------------------
 * # Algorithm 'SLIQ' developed by Mariusz Gromada
 * # R Package developed by Michal Draminski & Julian Zubek
 * #-------------------------------------------------------------------------------
 *******************************************************************************/
package dmLab.mcfs.attributesRI.measuresRI;

import dmLab.classifier.attributeIndicators.AttributeIndicators;
import dmLab.mcfs.MCFSParams;
import dmLab.mcfs.attributesRI.ExperimentIndicators;

public abstract class ImportanceMeasure
{
    public static String MEASURE_PROJECTIONS = "projections";
    public static String MEASURE_CLASSIFIERS = "classifiers";
    public static String MEASURE_NODES = "nodes";
    public static String MEASURE_RI_ROUGH = "RI_rough";
    public static String MEASURE_RI = "RI";
    
    public String name;
    public MCFSParams cfg;
    
    //********************************    
    public ImportanceMeasure(MCFSParams cfg)
    {
        this.cfg=cfg;
    }
    //********************************
    public abstract void flush();
    //********************************
    public abstract double calcAttrImportance(ExperimentIndicators experimentIndicators, AttributeIndicators indicators);    
    //********************************
    public abstract double calcAttrImportance();
    //********************************
}
